@@ -13,7 +13,7 @@
 ##############################################################################
 """Database connection support
 
-$Id: Connection.py 91987 2008-10-10 15:20:32Z tseaver $"""
+$Id: Connection.py 106543 2009-12-15 16:11:25Z jim $"""
 
 import logging
 import sys
@@ -332,6 +332,10 @@ class Connection(ExportImport, object):
         try:
             if self._txn_time is None:
                 self._txn_time = tid
+            elif tid < self._txn_time:
+                raise AssertionError("invalidations out of order, %r < %r"
+                                     % (tid, self._txn_time))
+
             self._invalidated.update(oids)
         finally:
             self._inv_lock.release()
